@@ -16,6 +16,7 @@ import cartopy.crs as ccrs
 from cartopy.util import add_cyclic_point
 from multiprocessing import Pool, cpu_count
 from functools import partial
+import seaborn as sns
 from . import utils, visual
 from .utils import (
     p_warning,
@@ -395,7 +396,7 @@ class ProxyRecord:
     def get_pseudo(self, psm, model_vars=None,
                    add_noise=False, noise='white', SNR=10, seed=None,
                    match_mean=False, match_var=False, verbose=False,
-                   calib_kws=None, forward_kws=None):
+                   calib_kws=None, forward_kws=None, colored_noise_kws=None):
         calib_kws = {} if calib_kws is None else calib_kws
         forward_kws = {} if forward_kws is None else forward_kws
 
@@ -411,17 +412,17 @@ class ProxyRecord:
         if verbose: utils.p_success(f'>>> ProxyRecord.pseudo created.')
 
         if add_noise:
-            sigma = np.nanstd(self.value) / SNR
+            sigma = np.nanstd(self.pseudo.value) / SNR
             if noise == 'white':
                 rng = np.random.default_rng(seed)
-                noise = rng.normal(0, sigma, np.size(self.value))
+                noise = rng.normal(0, sigma, np.size(self.pseudo.value))
             elif noise == 'colored':
                 colored_noise_kws = {} if colored_noise_kws is None else colored_noise_kws
-                _colored_noise_kws = {'seed': seed, 'alpha': 1, 't': self.time}
+                _colored_noise_kws = {'seed': seed, 'alpha': 1, 't': self.pseudo.time}
                 _colored_noise_kws.update(colored_noise_kws)
                 noise = utils.colored_noise(**_colored_noise_kws)
 
-            self.pseudo += noise
+            self.pseudo.value += noise / np.std(noise) * sigma
             if verbose: utils.p_success(f'>>> ProxyRecord.pseudo added with {noise} noise (SNR={SNR}).')
 
         if match_var or match_mean:
@@ -509,7 +510,114 @@ class ProxyRecord:
 
         return fig, ax
 
-    def dashboard(self, clim_units=None, clim_colors=None, figsize=[14, 8], scaled_pr=False, ms=200, stock_img=True, edge_clr='w',
+    def dashboard(self, figsize=[10, 8], ms=200, stock_img=True, edge_clr='w',
+        wspace=0.1, hspace=0.3, spec_method='wwz', pseudo_clr=None, **kwargs):
+        ''' Plot a dashboard of the proxy/pseudoproxy.
+        '''
+
+        if not hasattr(self, 'pseudo'):
+            raise ValueError('Need to get the pseudoproxy data.')
+
+        if 'color' not in kwargs and 'c' not in kwargs:
+            kwargs['color'] = visual.STYLE.colors_dict[self.ptype]
+
+        fig = plt.figure(figsize=figsize)
+
+        gs = gridspec.GridSpec(2, 3)
+        gs.update(wspace=wspace, hspace=hspace)
+        ax = {}
+
+        # plot proxy/pseudoproxy timeseries
+        ax['ts'] = plt.subplot(gs[0, :2])
+
+        _kwargs = {'label': 'real', 'zorder': 3, 'alpha': 0.7}
+        _kwargs.update(kwargs)
+        ax['ts'].plot(self.time, self.value, **_kwargs)
+
+        time_lb = visual.make_lb(self.time_name, self.time_unit)
+        value_lb = visual.make_lb(self.value_name, self.value_unit)
+
+        ax['ts'].set_ylabel(value_lb)
+        ax['ts'].set_xlabel(time_lb)
+        ax['ts'].plot(
+            self.pseudo.time, self.pseudo.value,
+            color=pseudo_clr, label='pseudo')
+        ax['ts'].legend(loc='upper left', ncol=2)
+        title = f'{self.pid} ({self.ptype})'
+        if self.seasonality is not None:
+            title += f'\nSeasonality: {self.seasonality}'
+        ax['ts'].set_title(title)
+
+        # plot probability density
+        ax['pd'] = plt.subplot(gs[0, 2], sharey=ax['ts'])
+        df_real = pd.DataFrame()
+        df_real['value'] = self.value
+        df_real['year'] = [int(t) for t in self.time]
+        df_real['dataset'] = 'real'
+
+        df_pseudo = pd.DataFrame()
+        df_pseudo['value'] = self.pseudo.value
+        df_pseudo['year'] = [int(t) for t in self.pseudo.time]
+        df_pseudo['dataset'] = 'pseudo'
+
+        df = pd.concat([df_real, df_pseudo])
+        df['all'] = ''
+        sns.violinplot(
+            data=df, x='all', y='value', ax=ax['pd'],
+            split=True, hue='dataset', inner='quart',
+            palette={'real': ax['ts'].lines[0].get_color(), 'pseudo': ax['ts'].lines[1].get_color()},
+        )
+        ax['pd'].set_ylabel('')
+        ax['pd'].set_xlabel('')
+        ax['pd'].tick_params(axis='y', colors='none')
+        ax['pd'].yaxis.set_ticks_position('none') 
+        ax['pd'].tick_params(axis='x', colors='none')
+        ax['pd'].xaxis.set_ticks_position('none') 
+        ax['pd'].set_title('Probability Distribution')
+        ax['pd'].legend_ = None
+            
+        # plot map
+        ax['map'] = plt.subplot(gs[1, 2], projection=ccrs.Orthographic(central_longitude=self.lon, central_latitude=self.lat))
+        ax['map'].set_global()
+        if stock_img:
+            ax['map'].stock_img()
+
+        transform=ccrs.PlateCarree()
+        ax['map'].scatter(
+            self.lon, self.lat, marker=visual.STYLE.markers_dict[self.ptype],
+            s=ms, c=visual.STYLE.colors_dict[self.ptype], edgecolor=edge_clr, transform=transform,
+        )
+        ax['map'].set_title(f'lat: {self.lat:.2f}, lon: {self.lon:.2f}')
+
+        # plot spectral analysis
+        try:
+            import pyleoclim as pyleo
+        except:
+            raise ImportError('Need to install pyleoclim: `pip install pyleoclim`.')
+
+        ax['psd'] = plt.subplot(gs[1, :2])
+
+        ts, psd = {}, {}
+        ts['real'] = pyleo.Series(time=self.time, value=self.value)
+        psd['real'] = ts['real'].spectral(method=spec_method)
+        psd['real'].plot(ax=ax['psd'], **_kwargs)
+
+        ts['pseudo'] = pyleo.Series(time=self.pseudo.time, value=self.pseudo.value)
+        psd['pseudo'] = ts['pseudo'].slice([self.time.min(), self.time.max()]).spectral(method=spec_method)
+        psd['pseudo'].plot(ax=ax['psd'], color=pseudo_clr, label='pseudo')
+
+        ax['psd'].legend_ = None
+        ax['psd'].text(
+            x=0.95, y=0.97, s=f'Timespan: {int(self.time.min())}-{int(self.time.max())}',
+            horizontalalignment='right',
+            verticalalignment='top',
+            transform=ax['psd'].transAxes,
+        )
+        ax['psd'].set_xlabel('Period [yrs]')
+
+        return fig, ax
+
+    def dashboard_clim(self, clim_units=None, clim_colors=None, figsize=[14, 8], scaled_pr=False, ms=200, stock_img=True, edge_clr='w',
         wspace=0.3, hspace=0.5, spec_method='wwz', **kwargs):
         ''' Plot a dashboard of the proxy/pseudoproxy along with the climate signal.
 
@@ -585,7 +693,6 @@ class ProxyRecord:
             self.lon, self.lat, marker=visual.STYLE.markers_dict[self.ptype],
             s=ms, c=kwargs['color'], edgecolor=edge_clr, transform=transform,
         )
-        ax['map'] = plt.subplot(gs[nclim:, 2])
 
         # plot spectral analysis
         try:
@@ -762,7 +869,7 @@ class ProxyDatabase:
         if not isinstance(df, pd.DataFrame):
             err_msg = 'the input df should be a Pandas DataFrame.'
             if verbose:
-                utils.p_fail(f'ProxyDatabase.load_df() >>> {err_msg}')
+                utils.p_fail(f'ProxyDatabase.from_df() >>> {err_msg}')
             raise TypeError(err_msg)
 
         records = OrderedDict()
@@ -1003,9 +1110,13 @@ class ProxyDatabase:
             time_list.append(pobj.time)
 
         df = pd.DataFrame({'lat': self.lats, 'lon': self.lons, 'type': self.type_list, 'time': time_list, 'pid': self.pids})
-        fig, ax = visual.plot_proxies(df, **kws)
 
-        return fig, ax
+        if 'return_gs' in kws and kws['return_gs'] is True:
+            fig, ax, gs = visual.plot_proxies(df, **kws)
+            return fig, ax, gs
+        else:
+            fig, ax = visual.plot_proxies(df, **kws)
+            return fig, ax
 
 
     def plotly(self, **kwargs):
@@ -1251,8 +1362,8 @@ class ProxyDatabase:
     def to_df(self):
         ''' Convert the proxy database to a `pandas.DataFrame`.'''
         df = pd.DataFrame(columns=['pid', 'lat', 'lon', 'ptype', 'time', 'value'])
-        df['time'] = df['time'].astype(object)
-        df['value'] = df['value'].astype(object)
+        # df['time'] = df['time'].astype(object)  # not necessary after pandas 1.5.2
+        # df['value'] = df['value'].astype(object) # not necessary after pandas 1.5.2
 
         i = 0
         for pid, pobj in self.records.items():
@@ -1270,7 +1381,7 @@ class ProxyDatabase:
         ''' Convert the proxy database to a `xarray.Dataset`
 
         Args:
-            annaulize (bool): annaulize the proxy records with `months`
+            annualize (bool): annualize the proxy records with `months`
             months (list): months for annulization
             verbose (bool, optional): print verbose information. Defaults to False.
         '''
@@ -1280,12 +1391,20 @@ class ProxyDatabase:
             if np.min(pobj.time) <= 0:
                 pid_truncated.append(pobj.pid)
                 pobj = pobj.slice([1, np.max(pobj.time)])
+
             if annualize:
                 pobj = pobj.annualize(months=months)
+
             da = pobj.to_da()
+
+            # remove potential duplicated indexes
+            _, index = np.unique(da['time'], return_index=True)
+            da = da.isel(time=index)
+
             if annualize:
                 da = da.rename({'time': 'year'})
                 da['year'] = np.array([int(t) for t in pobj.time])
+
             da_dict[pobj.pid] = da
 
         if verbose:
@@ -1312,7 +1431,7 @@ class ProxyDatabase:
 
         Args:
             path (str): the path to save the file.
-            annaulize (bool): annaulize the proxy records with `months`
+            annualize (bool): annualize the proxy records with `months`
             months (list): months for annulization
             verbose (bool, optional): print verbose information. Defaults to False.
         '''
