@@ -253,9 +253,9 @@ def gcd(lat1, lon1, lat2, lon2):
 	km = 6367 * c
 	return km
 
-def annualize(time=None, value=None, da=None, months=list(range(1, 13))):
+def annualize(time=None, value=None, da=None, months=None):
     # convert negative months to support expressions like [-12, 1, 2]
-    months = np.abs(months)
+    months = list(range(1, 13)) if months is None else np.abs(months)
 
     if da is None:
         dates = year_float2datetime(time)
@@ -265,7 +265,8 @@ def annualize(time=None, value=None, da=None, months=list(range(1, 13))):
     else:
         da_wk = da
 
-    sda = da_wk.sel(time=da_wk.time.dt.month.isin(months))
+    # sda = da_wk.sel(time=da_wk.time.dt.month.isin(months))
+    sda = da_wk.sel(time=da_wk['time.month'].isin(months))
     anchor = ['JAN', 'FEB', 'MAR', 'APR', 'MAY', 'JUN', 'JUL', 'AUG', 'SEP', 'OCT', 'NOV', 'DEC']
     idx = months[-1]-1
     sda_ann = sda.resample(time=f'A-{anchor[idx]}').mean()
@@ -458,15 +459,16 @@ def regrid_field_curv_rect(field, lat_curv, lon_curv, dlat=1, lon_range=None, la
 def coefficient_efficiency(ref, test, valid=None):
     """ Compute the coefficient of efficiency for a test time series, with respect to a reference time series.
 
-    Inputs:
-    test:  test array
-    ref:   reference array, of same size as test
-    valid: fraction of valid data required to calculate the statistic
+    Args:
+        ref (numpy.ndarray):   reference array, of same size as test
+        test (numpy.ndarray):  test array
+        valid (float): fraction of valid data required to calculate the statistic
 
-    Note: Assumes that the first dimension in test and ref arrays is time!!!
+    Note:
+        Assumes that the first dimension in test and ref arrays is time!!!
 
-    Outputs:
-    CE: CE statistic calculated following Nash & Sutcliffe (1970)
+    Returns:
+        CE (float): CE statistic calculated following Nash & Sutcliffe (1970)
     """
 
     # check array dimensions
@@ -524,4 +526,104 @@ def geo_mean(da, lat_min=-90, lat_max=90, lon_min=0, lon_max=360, lat_name='lat'
 
     wgts = np.cos(np.deg2rad(dac[lat_name]))
     m = dac.weighted(wgts).mean((lon_name, lat_name))
-    return m
\ No newline at end of file
+    return m
+
+def colored_noise(alpha, t, f0=None, m=None, seed=None):
+    ''' Generate a colored noise timeseries
+
+    Parameters
+    ----------
+    alpha : float
+        exponent of the 1/f^alpha noise
+    t : float
+        time vector of the generated noise
+    f0 : float
+        fundamental frequency
+    m : int
+        maximum number of the waves, which determines the highest frequency of the components in the synthetic noise
+
+    Returns
+    -------
+    y : array
+        the generated 1/f^alpha noise
+
+    References
+    ----------
+    Eq. (15) in Kirchner, J. W. Aliasing in 1/f(alpha) noise spectra: origins, consequences, and remedies.
+        Phys Rev E Stat Nonlin Soft Matter Phys 71, 066110 (2005).
+    '''
+    n = np.size(t)  # number of time points
+    y = np.zeros(n)
+
+    if f0 is None:
+        f0 = 1/n  # fundamental frequency
+    if m is None:
+        m = n//2
+
+    k = np.arange(m) + 1  # wave numbers
+
+    rng = np.random.default_rng(seed)
+    theta = rng.random(int(m))*2*np.pi  # random phase
+    for j in range(n):
+        coeff = (k*f0)**(-alpha/2)
+        sin_func = np.sin(2*np.pi*k*f0*t[j] + theta)
+        y[j] = np.sum(coeff*sin_func)
+
+    return y
+
+def colored_noise_2regimes(alpha1, alpha2, f_break, t, f0=None, m=None, seed=None):
+    ''' Generate a colored noise timeseries with two regimes
+
+    Parameters
+    ----------
+    alpha1, alpha2 : float
+        the exponent of the 1/f^alpha noise
+    f_break : float
+        the frequency where the scaling breaks
+    t : float
+        time vector of the generated noise
+    f0 : float
+        fundamental frequency
+    m : int
+        maximum number of the waves, which determines the highest frequency of the components in the synthetic noise
+
+    Returns
+    -------
+    y : array
+        the generated 1/f^alpha noise
+
+    References
+    ----------
+     Eq. (15) in Kirchner, J. W. Aliasing in 1/f(alpha) noise spectra: origins, consequences, and remedies.
+         Phys Rev E Stat Nonlin Soft Matter Phys 71, 066110 (2005).
+    '''
+    n = np.size(t)  # number of time points
+    y = np.zeros(n)
+
+    if f0 is None:
+        f0 = 1/n  # fundamental frequency
+    if m is None:
+        m = n//2  # so the aliasing is limited
+
+    k = np.arange(m) + 1  # wave numbers
+
+    if seed is not None:
+        np.random.seed(seed)
+
+    theta = np.random.rand(int(m))*2*np.pi  # random phase
+
+    f_vec = k*f0
+    regime1= k*f0>=f_break
+    regime2= k*f0<=f_break
+    f_vec1 = f_vec[regime1]
+    f_vec2 = f_vec[regime2]
+    s = np.exp(alpha1/alpha2*np.log(f_vec1[0])) / f_vec2[-1]
+
+    for j in range(n):
+        coeff = np.ndarray((np.size(f_vec)))
+        coeff[regime1] = f_vec1**(-alpha1/2)
+        coeff[regime2] = (s*f_vec2)**(-alpha2/2)
+        sin_func = np.sin(2*np.pi*k*f0*t[j] + theta)
+        y[j] = np.sum(coeff*sin_func)
+
+    return y
\ No newline at end of file
